ExecutionArgs

Struct ExecutionArgs 

pub struct ExecutionArgs {
    pub script: ResolvedScriptContents,
    pub interpreter: Option<String>,
    pub env_vars: IndexMap<String, String>,
    pub secrets: IndexMap<String, String>,
    pub runtime: RuntimeEnv,
    pub build_prefix: Option<PathBuf>,
    pub run_prefix: PathBuf,
    pub work_dir: PathBuf,
    pub sandbox_config: Option<SandboxConfiguration>,
    pub env_isolation: EnvironmentIsolation,
}
Arguments for executing a script in a given interpreter.

Fields

script: ResolvedScriptContents

Contents of the script to execute

interpreter: Option<String>

Explicit interpreter requested for the script, if any.

env_vars: IndexMap<String, String>

Environment variables to set before executing the script

secrets: IndexMap<String, String>

Secrets to set as env vars and replace in the output

runtime: RuntimeEnv

The environment rattler-build is running in: process environment variables (including PATH) and the platform scripts execute on.

build_prefix: Option<PathBuf>

The build prefix that should contain the interpreter to use

run_prefix: PathBuf

The prefix to use for the script execution

work_dir: PathBuf

The working directory (cwd) in which the script should execute

sandbox_config: Option<SandboxConfiguration>

The sandbox configuration to use for the script execution

env_isolation: EnvironmentIsolation

The environment isolation mode